imprint(1)

imprint - converts text files to PostScript, similar to Adobe enscript(tm)

As shipped in IRIX 6.5.7. Unchanged since IRIX 6.5.

NAME
     imprint - converts text files to PostScript, similar to Adobe
     enscript(tm)

SYNOPSIS
     imprint [-1] [-2] [-B] [-b headerText]
             [-c] [-d printerName] [-F hfontNameSize]
             [-f fontNameSize] [-G] [-g] [-h]
             [-L maxLines] [-l] [-m] [-n numCopies]
             [-o printerOptions] [-p outFilename] [-q]
             [-r] [-R] [-t bannerTitle] [-w]
             [text file ...]

DESCRIPTION
     imprint formats text files using the PostScript page description language
     and prints these files on a PostScript capable printer.  The program
     provides a wide variety of formatting options including multiple column
     output, page rotation, font selection and page decoration.

   Text File Input
     One or more text files can be specified on the command line. If no files
     are specified on the command line, imprint will read from the standard
     input. Currently, imprint can accept plain text files in a number of
     languages. The program has successfully formatted English, French,
     German, and Russian (cyrillic) text files and theoretically should be
     able to handle any language that can be expressed using an Adobe Type 1
     font in a horizontal writing direction.  imprint cannot currently handle
     Adobe Type 0 composite fonts or vertical writing directions.

     Besides plain text files, imprint can accept text files that contain
     formatting control characters and special escape sequences. The most
     common example of such files are formatted nroff manual pages.  imprint
     has successfully handled the complex formatting produced by the tbl and
     eqn programs. The following control characters and escape sequences are
     recognized by imprint:

             Name        Char   Code   Description
             _________________________________________________________
             Null               0x00   No action
             Bell        ^G     0x07   Audible bell
             Backspace   ^H     0x08   Reverse one character
             H Tab       ^I     0x09   Forward to next multiple of 8
             Newline     ^J     0x0A   Start new line
             V Tab       ^K     0x0B   Down one line
             Formfeed    ^L     0x0C   Begin new page or column
             Return      ^M     0x0D   Reverse to start of line
             Shift Out   ^N     0x0E   No action
             Shift In    ^O     0x0F   No action
             Esc                0x1B   Begin escape sequence
             Esc-7                     Reverse full line feed

             Esc-8                     Reverse half line feed
             Esc-9                     Forward half line feed
             Esc-D                     Guady header left box text
             Esc-H                     Gaudy header filename area text
             Esc-U                     Gaudy user comment area text
             Esc-F                     Font change sequence

     See the Special Escape Sequences section below for details on the Esc-D,
     Esc-H, Esc-U and Esc-F sequences.

     Control characters and escape sequences not listed above will cause
     imprint to issue a warning indicating the offending character and its
     location in the text file. To prevent inadvertently attempting to format
     a binary file, imprint will terminate the processing of any file that
     contains more than fifty unrecognized characters unless the -g option has
     been specified (see below). To ensure the proper processing of text files
     the international locale should be established either by setting the LANG
     environment variable prior to running imprint.

   PostScript Output
     imprint produces Level 1 PostScript code formatted in compliance with the
     Adobe Document Structuring Conventions, Version 3.0. The output
     PostScript data sent to the printer is 7-bit clean even when the input
     data is not.

   Command Line Options
     -1        Format text into a single column. This is the default.

     -2        Format text into two columns. Typically, when using two
               columns, the font size should be reduced to avoid excessive
               line wrapping.

     -B        By default, imprint places a simple header at the top of each
               page.  This header consists of the date, time, file pathname
               and page number.  Specifying the -B switch omits the header.

     -b headerText
               Specifies a comment to be placed on the page header. For the
               default header, the headerText will replace the file pathname.
               If the -G option is specified, the headerText will be placed
               above the file pathname.

     -c        By default, imprint wraps text lines that are too long for the
               column. The -c option causes long text lines to be clipped
               rather than wrapped to the next line.

     -d printerName
               If the -p option is not specified, -d specifies a destination
               printer for which the text files are to be formatted and
               printed.  printername is the name of the printer as registered
               with the printer spooling system (see printers(1M) for
               information on printer installation). The printer may be
               physically attached to the system or it may be a network
               printer. If a printer has not been specified, the system
               default printer will be used. If the -p option is specified,
               the text files are formatted for the specified printer but are
               sent instead to the specified output file. In this case, if a
               printer has not been specified, the text files are formatted
               assuming a generic environment.

     -F hfontNameSize
               Specifies the font name and point size to use for the default
               page header.  The default header font is Courier-Bold10. Note
               that this option has no effect when the gaudy header is used.
               See the Fonts section below for additional information.

     -f fontNameSize
               Specifies the font name and point size to use for the body
               text. The default body font is normally Courier10. When rotated
               (-r), two-column (-2) formatting is specified, the default body
               font becomes Courier7. See the Fonts section below for
               additional information.

     -G        Provides a more elaborate page decoration and header than the
               default header.  The date, time, file pathname and page number
               are provided along with a space for a user supplied comment
               (see -b).

     -g        imprint recognizes plain text characters, a number of common
               control characters and a set of special escape sequences. All
               other characters cause a warning message to be issued
               identifying the character and its location in the input file.
               If more than 50 characters in a file are unrecognized, the
               processing of that file terminates. This prevents inadvertently
               attempting to format a binary file. If a file is to be
               formatted that contains unrecognizable characters, the -g
               option should be specified. This silences all unrecognized
               character warnings and allows an unlimited number of
               unrecognized characters to be processed.

     -h        Specifies that a banner page should not be printed.

     -L maxLines
               Normally, imprint places as many lines of text on the page as
               will fit (equivalent to specifying maxLines as 0).  The -L
               option places a maximum limit on the number of lines placed on
               a page or column.  The number of lines actually produced will
               be either maxLines or the number that can fit on the page
               whichever is less.

     -l        Specifies a line printer emulation mode. In this mode page
               headers are omitted and 66 lines per page are printed. This
               mode should be specified when printing preformatted nroff
               manual pages.
     -m        Causes mail to be sent after the text files have been printed.
               This option has no effect when the -p option is specified.

     -n numCopies
               Prints numCopies of each page. One copy is the default. When
               the -p option is specified a single copy of the output is
               provided and the -n option is ignored.

     -o printerOptions
               Allows printer specific options to be specified. See the lp(1)
               manual page for details on this option.

     -p outFilename
               Sends the PostScript output to the specified file rather than
               to a printer. If outFilename is specified as '-', the output is
               sent to the standard output. If a printer has been specified,
               the output is formatted for that printer (i.e margins, page
               size, etc.). If a printer has not been specified, a generic
               environment is assumed.

     -q        Normally, imprint displays summary information when it has
               completed formatting the text files. The -q option runs the
               program in silent mode and no summary information is printed.
               Errors and warnings cannot be silenced.

     -R        Specifies non-rotated orientation and is the default. This is
               typically a portrait orientation.

     -r        Specifies that the text columns should be rotated 90 degrees
               counter- clockwise. This is typically a landscape orientation.

     -t bannerTitle
               Specifies a banner page title for the print job.

     -w        Causes a message to be sent after the text files have been
               printed. This option has no effect when the -p option is
               specified.

   Fonts
     imprint can utilize the fonts found in the directory /usr/lib/DPS/AFM.
     The full font name may be specified or one of the font name abbreviations
     listed in the table below may be used.

                    Full Name                      Abbreviation
                    ___________________________________________
                    Courier                        C
                    Courier-Bold                   CB
                    Courier-BoldOblique            CBO
                    Courier-Oblique                CO
                    Helvetica                      H

                    Helvetica-Bold                 HB
                    Helvetica-BoldOblique          HBO
                    Helvetica-Oblique              HO
                    Symbol                         S
                    Times-Bold                     TB
                    Times-BoldItalic               TBI
                    Times-Italic                   TI
                    Times-Roman                    T
                    AvantGarde-Book                AGB
                    AvantGarde-BookOblique         AGBO
                    AvantGarde-Demi                AGD
                    AvantGarde-DemiOblique         AGDO
                    Bookman-Demi                   BD
                    Bookman-DemiItalic             BDI
                    Bookman-Light                  BL
                    Bookman-LightItalic            BLI
                    Helvetica-Narrow               HN
                    Helvetica-Narrow-Bold          HNB
                    Helvetica-Narrow-BoldOblique   HNBO
                    Helvetica-Narrow-Oblique       HNO
                    NewCenturySchlbk-Bold          NCSB
                    NewCenturySchlbk-BoldItalic    NCSBI
                    NewCenturySchlbk-Italic        NCSI
                    NewCenturySchlbk-Roman         NCSR
                    Palatino-Bold                  PB
                    Palatino-BoldItalic            PBI
                    Palatino-Italic                PI
                    Palatino-Roman                 PR
                    ZapfChancery-MediumItalic      ZCMI
                    ZapfDingbats                   ZD

     If a font is specified that is not found in the font directory, Courier
     will be substituted. Note that a fixed-width font such as Courier should
     be used when printing tabular material and preformatted manual pages.

   Special Escape Sequences
     imprint recognizes a number of special escape sequences. These sequences
     can be embedded in a text file to change header text and switch fonts
     during processing of  the file.  The escape sequences are compatible with
     those used by the enscript program from the Adobe TranScript product. The
     sequences are:

            Escape Sequence      Description
            __________________________________________________________
            Esc-D(top)(bottom)   Gaudy header left box text
            Esc-HheaderText      Gaudy header filename area text
            Esc-UcommentText     Gaudy user comment area text
            Esc-Fc               Font change sequence (see text2ps(1))

EXAMPLES
     1.   Printing a preformatted manual page to the default printer:

          pcat csh.z | imprint -l


     2.   Printing a file to the printer 'dj' in two column, landscape mode
          with a gaudy header:

          imprint -d dj -2rG /etc/passwd


NOTES
     1.   the imprint program runs the text2ps program to perform the work for
          formatting the text files and the lp program to print them. Refer to
          the manual pages for these programs for detailed information on
          formatting and printing issues.

     2.   The PostScript output produced by imprint conforms to the Adobe
          PostScript Document Structuring Conventions Version 3.0 as specified
          in Appendix G of the "PostScript Language Reference Manual", 2nd
          edition.

     3.   If imprint is given an unrecognized or incomplete command line
          option switch, it will print a warning message to the standard
          error, ignore the option and continue processing.

     4.   If a file is specified on the command line, imprint will not read
          its stdin for text files.

     5.   imprint can only process a single file when reading from standard
          input.

     6.   Use a of proportional spaced font or dynamically changing fonts when
          formatting manual pages can cause misformatting of tables.

ENVIRONMENT
     If the environment variable IMPRINT is set, imprint will treat the
     contents of this variable as command line options. For example, if
     IMPRINT has been set to '-2rG', imprint will print in two-column, rotated
     mode with a gaudy header whenever it is invoked. Options specified on the
     command line override environment variable options.

FILES
     /usr/sbin/imprint         Program file
     /usr/lib/print/text2ps    Text formatting filter
     /usr/bin/lp               Printing program

SEE ALSO
     text2ps(1), lp(1)